@@ -21,8 +21,8 @@
 *
 * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
-#include "ui_skgdebugpluginwidget_base.h"
 #include "skgtabpage.h"
+#include "ui_skgdebugpluginwidget_base.h"
 
 /**
  * This file is a plugin for debug
@@ -70,7 +70,7 @@ private Q_SLOTS:
 private:
     Q_DISABLE_COPY(SKGDebugPluginWidget)
 
-    Ui::skgdebugplugin_base ui;
+    Ui::skgdebugplugin_base ui{};
 };
 
 #endif  // SKGDEBUGPLUGINWIDGET_H
