@@ -356,6 +356,9 @@ SKGError SKGImportPluginCsv::importFile()
                             // Read line
                             QString line = stream.readLine().trimmed();
                             if (!line.isEmpty()) {
+                                if (line.startsWith(QLatin1String("\""))) {
+                                    currentLine.clear();
+                                }
                                 currentLine += line;
 
                                 // Get date
@@ -366,16 +369,18 @@ SKGError SKGImportPluginCsv::importFile()
                                     lines.push_back(currentLine);
                                     currentLine.clear();
 
-                                    if (posdate < field.count()) {
-                                        dates.push_back(field.value(posdate).remove(QStringLiteral(" 00:00:00")).trimmed());
-                                    }
+                                    if (field.count() == m_csvMapping.count()) {
+                                        if (posdate < field.count()) {
+                                            dates.push_back(field.value(posdate).remove(QStringLiteral(" 00:00:00")).trimmed());
+                                        }
 
-                                    // Check if all amounts are positive
-                                    if (modeAutoCreditDebit) {
-                                        for (int i = 0; modeAutoCreditDebit && i < nbAmount; ++i) {
-                                            QString s = field.at(amountIndexes.at(i)).trimmed();
-                                            if (!s.isEmpty() && SKGServices::stringToDouble(s) < 0) {
-                                                modeAutoCreditDebit = false;
+                                        // Check if all amounts are positive
+                                        if (modeAutoCreditDebit) {
+                                            for (int i = 0; modeAutoCreditDebit && i < nbAmount; ++i) {
+                                                QString s = field.at(amountIndexes.at(i)).trimmed();
+                                                if (!s.isEmpty() && SKGServices::stringToDouble(s) < 0) {
+                                                    modeAutoCreditDebit = false;
+                                                }
                                             }
                                         }
                                     }
@@ -470,7 +475,7 @@ SKGError SKGImportPluginCsv::importFile()
                                                                  headerIndex + i + 1, nbcol, atts.count()));
                         }
                         QString linecleaned;
-                        for (int z = 0; z < nbcol; ++z) {
+                        for (int z = 0; !err && z < nbcol; ++z) {
                             if (!m_csvMapping[z].isEmpty()) {
                                 if (!linecleaned.isEmpty()) {
                                     linecleaned += getCSVSeparator();
