@@ -390,7 +390,7 @@ int SKGImportPluginOfx::ofxTransactionCallback(struct OfxTransactionData data, v
     SKGImportPluginOfx::m_ofxError = getAccount(data.account_ptr, doc, account);
     if (!SKGImportPluginOfx::m_ofxError) {
         // Get operation date
-        QDate date = QDateTime::fromTime_t(data.date_initiated).date();
+        QDate date = QDateTime::fromTime_t(static_cast<bool>(data.date_initiated_valid) ? data.date_initiated : data.date_posted).date();
 
         // Get unit
         SKGUnitObject unit;
