@@ -21,9 +21,9 @@
  *
  * @author Stephane MANKOWSKI
  */
-#include <qtimer.h>
-#include "ui_skgcalculatorpluginwidget_base.h"
 #include "skgtabpage.h"
+#include "ui_skgcalculatorpluginwidget_base.h"
+#include <qtimer.h>
 
 class SKGObjectModel;
 
@@ -120,7 +120,7 @@ private:
     Q_DISABLE_COPY(SKGCalculatorPluginWidget)
     void computeInterest();
 
-    Ui::skgcalculatorplugin_base ui;
+    Ui::skgcalculatorplugin_base ui{};
     SKGObjectModel* m_objectModel;
     QTimer m_timer;
 };
