@@ -25,24 +25,24 @@
 #include <qaction.h>
 
 #include <qdom.h>
-#include <qwidget.h>
+#include <qevent.h>
 #include <qgraphicsscene.h>
 #include <qheaderview.h>
-#include <qevent.h>
+#include <qwidget.h>
 
+#include "skgcategoryobject.h"
+#include "skgdocumentbank.h"
 #include "skgmainpanel.h"
-#include "skgtraces.h"
 #include "skgobjectmodel.h"
 #include "skgsortfilterproxymodel.h"
-#include "skgdocumentbank.h"
-#include "skgcategoryobject.h"
+#include "skgtraces.h"
 #include "skgtransactionmng.h"
 
 SKGCategoriesPluginWidget::SKGCategoriesPluginWidget(QWidget* iParent, SKGDocumentBank* iDocument)
     : SKGTabPage(iParent, iDocument)
 {
     SKGTRACEINFUNC(10);
-    if (!iDocument) {
+    if (iDocument == nullptr) {
         return;
     }
 
@@ -51,7 +51,7 @@ SKGCategoriesPluginWidget::SKGCategoriesPluginWidget(QWidget* iParent, SKGDocume
     // Define action
     QStringList overlaycategories;
     overlaycategories.push_back(QStringLiteral("view-categories"));
-    if (SKGMainPanel::getMainPanel()) {
+    if (SKGMainPanel::getMainPanel() != nullptr) {
         auto addCategoryAction = new QAction(SKGServices::fromTheme(QStringLiteral("list-add"), overlaycategories), i18nc("Verb", "Add category"), this);
         connect(addCategoryAction, &QAction::triggered, this, &SKGCategoriesPluginWidget::onAddCategory);
         SKGMainPanel::getMainPanel()->registerGlobalAction(QStringLiteral("edit_add_category"), addCategoryAction, true, QStringList() << QStringLiteral("category"), 1, -1, 450);
@@ -74,7 +74,7 @@ SKGCategoriesPluginWidget::SKGCategoriesPluginWidget(QWidget* iParent, SKGDocume
     ui.kModifyCategoryButton->setIcon(SKGServices::fromTheme(QStringLiteral("dialog-ok")));
     ui.kDeleteUnusedButton->setIcon(SKGServices::fromTheme(QStringLiteral("edit-delete")));
 
-    ui.kCategoriesView->setModel(new SKGObjectModel(static_cast<SKGDocumentBank*>(getDocument()), QStringLiteral("v_category_display"), QStringLiteral("1=0"), this, QStringLiteral("rd_category_id"), false));
+    ui.kCategoriesView->setModel(new SKGObjectModel(qobject_cast<SKGDocumentBank*>(getDocument()), QStringLiteral("v_category_display"), QStringLiteral("1=0"), this, QStringLiteral("rd_category_id"), false));
     ui.kCategoriesView->getView()->setRootIsDecorated(true);
     ui.kCategoriesView->getView()->setAnimated(false);  // Not compatible with double click
     ui.kCategoriesView->getView()->resizeColumnToContents(0);
@@ -103,12 +103,12 @@ SKGCategoriesPluginWidget::~SKGCategoriesPluginWidget()
 
 bool SKGCategoriesPluginWidget::eventFilter(QObject* iObject, QEvent* iEvent)
 {
-    if (iEvent && iEvent->type() == QEvent::KeyPress) {
-        QKeyEvent* keyEvent = static_cast<QKeyEvent*>(iEvent);
+    if ((iEvent != nullptr) && iEvent->type() == QEvent::KeyPress) {
+        auto* keyEvent = dynamic_cast<QKeyEvent*>(iEvent);
         if ((keyEvent->key() == Qt::Key_Return || keyEvent->key() == Qt::Key_Enter) && iObject == this) {
-            if (QApplication::keyboardModifiers() &Qt::ControlModifier && ui.kAdd->isEnabled()) {
+            if ((QApplication::keyboardModifiers() & Qt::ControlModifier) != 0u && ui.kAdd->isEnabled()) {
                 ui.kAdd->click();
-            } else if (QApplication::keyboardModifiers() &Qt::ShiftModifier && ui.kModifyCategoryButton->isEnabled()) {
+            } else if ((QApplication::keyboardModifiers() &Qt::ShiftModifier) != 0u && ui.kModifyCategoryButton->isEnabled()) {
                 ui.kModifyCategoryButton->click();
             }
         }
@@ -139,7 +139,7 @@ void SKGCategoriesPluginWidget::onSelectionChanged()
     int nb = ui.kLayout->count();
     for (int i = 0; i < nb; ++i) {
         QLayoutItem* item = ui.kLayout->itemAt(0);
-        if (item) {
+        if (item != nullptr) {
             ui.kLayout->removeItem(item);
             delete item->widget();
             delete item;
@@ -254,7 +254,7 @@ void SKGCategoriesPluginWidget::onAddCategory()
             SKGCategoryObject parentCat(selection[0]);
             name = parentCat.getFullName() % OBJECTSEPARATOR % name;
         }
-        IFOKDO(err, SKGCategoryObject::createPathCategory(static_cast<SKGDocumentBank*>(getDocument()), name, cat, false, true))
+        IFOKDO(err, SKGCategoryObject::createPathCategory(qobject_cast<SKGDocumentBank*>(getDocument()), name, cat, false, true))
 
         // Send message
         IFOKDO(err, cat.getDocument()->sendMessage(i18nc("An information message", "The category '%1' has been created", cat.getDisplayName()), SKGDocument::Hidden));
@@ -331,7 +331,7 @@ void SKGCategoriesPluginWidget::onUpdateCategory()
 void SKGCategoriesPluginWidget::onDeleteUnused()
 {
     QAction* act = SKGMainPanel::getMainPanel()->getGlobalAction(QStringLiteral("clean_delete_unused_categories"));
-    if (act) {
+    if (act != nullptr) {
         act->trigger();
     }
 }
