@@ -132,7 +132,7 @@ SKGAdviceList SKGPayeePlugin::advice(const QStringList& iIgnoredAdvice)
     // Check unused payee
     if (!iIgnoredAdvice.contains(QStringLiteral("skgpayeeplugin_unused"))) {
         bool exist = false;
-        m_currentBankDocument->existObjects(QStringLiteral("payee"), QStringLiteral("NOT EXISTS (SELECT 1 FROM operation WHERE operation.r_payee_id=payee.id)"), exist);
+        m_currentBankDocument->existObjects(QStringLiteral("payee LEFT JOIN operation ON operation.r_payee_id=payee.id"), QStringLiteral("operation.id IS NULL"), exist);
         if (exist) {
             SKGAdvice ad;
             ad.setUUID(QStringLiteral("skgpayeeplugin_unused"));
@@ -178,7 +178,7 @@ void SKGPayeePlugin::deleteUnusedPayees() const
         SKGBEGINTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Delete unused payees"), err);
 
         // Modification of payee object
-        QString sql = QStringLiteral("DELETE FROM payee WHERE NOT EXISTS (SELECT 1 FROM operation WHERE operation.r_payee_id=payee.id)");
+        QString sql = QStringLiteral("DELETE FROM payee  WHERE id IN (SELECT payee.id FROM payee LEFT JOIN operation ON operation.r_payee_id=payee.id WHERE operation.id IS NULL)");
         err = m_currentBankDocument->executeSqliteOrder(sql);
     }
 
