@@ -21,8 +21,8 @@
 *
 * @author Stephane MANKOWSKI
 */
-#include "ui_skgscheduledpluginwidget_base.h"
 #include "skgtabpage.h"
+#include "ui_skgscheduledpluginwidget_base.h"
 
 class SKGDocumentBank;
 
@@ -44,7 +44,7 @@ public:
     /**
      * Default Destructor
      */
-    virtual ~SKGScheduledPluginWidget();
+    ~SKGScheduledPluginWidget() override;
 
     /**
      * Get the current state
@@ -52,27 +52,27 @@ public:
      * @return a string containing all information needed to set the same state.
      * Could be an XML stream
      */
-    virtual QString getState() override;
+    QString getState() override;
 
     /**
      * Set the current state
      * MUST BE OVERWRITTEN
      * @param iState must be interpreted to set the state of the widget
      */
-    virtual void setState(const QString& iState) override;
+    void setState(const QString& iState) override;
 
     /**
      * Get attribute name to save the default state
      * MUST BE OVERWRITTEN
      * @return attribute name to save the default state.
      */
-    virtual QString getDefaultStateAttribute() override;
+    QString getDefaultStateAttribute() override;
 
     /**
      * Get the main widget
      * @return a widget
      */
-    virtual QWidget* mainWidget() override;
+    QWidget* mainWidget() override;
 
 protected:
     /**
@@ -81,7 +81,7 @@ protected:
      * @param iEvent event
      * @return In your reimplementation of this function, if you want to filter the event out, i.e. stop it being handled further, return true; otherwise return false.
      */
-    virtual bool eventFilter(QObject* iObject, QEvent* iEvent) override;
+    bool eventFilter(QObject* iObject, QEvent* iEvent) override;
 
 private Q_SLOTS:
     void onSelectionChanged();
@@ -94,7 +94,7 @@ private Q_SLOTS:
 private:
     Q_DISABLE_COPY(SKGScheduledPluginWidget)
 
-    Ui::skgscheduledplugin_base ui;
+    Ui::skgscheduledplugin_base ui{};
 };
 
 #endif  // SKGSCHEDULEDPLUGINWIDGET_H
