@@ -21,9 +21,9 @@
 *
 * @author Stephane MANKOWSKI
 */
-#include "ui_skgsearchpluginwidget_base.h"
-#include "skgtabpage.h"
 #include "skgruleobject.h"
+#include "skgtabpage.h"
+#include "ui_skgsearchpluginwidget_base.h"
 
 /**
  * A skrooge plugin to search and process operations
@@ -139,7 +139,7 @@ private:
     Q_DISABLE_COPY(SKGSearchPluginWidget)
 
     QString getXMLActionDefinition();
-    Ui::skgsearchplugin_base ui;
+    Ui::skgsearchplugin_base ui{};
 };
 
 #endif  // SKGSEARCHPLUGINWIDGET_H
