@@ -459,16 +459,25 @@ QVariant SKGObjectModel::computeData(const QModelIndex& iIndex, int iRole) const
                 if (impStatus == QStringLiteral("P")) {
                     return m_iconImportedChecked;
                 }
-            } else if (att == QStringLiteral("t_REFUND") || att == QStringLiteral("t_REALREFUND")) {
-                QString trackerName;
-                trackerName = obj->getAttribute(att);
-                if (!trackerName.isEmpty()) {
-                    SKGTrackerObject tracker(SKGObjectBase(getDocument(), QStringLiteral("refund")));  // Better performance if v_refund is not used
-                    tracker.setName(trackerName);
-                    tracker.load();
+            } else if (att == QStringLiteral("t_REFUND") || att == QStringLiteral("t_REALREFUND") || att == QStringLiteral("t_REFUNDDISPLAY")) {
+                if (att == QStringLiteral("t_REFUNDDISPLAY")) {
+                    if (obj->getAttribute(att).count(QStringLiteral("(")) > 1) {
+                        att.clear();
+                    } else {
+                        att = QStringLiteral("t_REFUND");
+                    }
+                }
+                if (!att.isEmpty()) {
+                    QString trackerName;
+                    trackerName = obj->getAttribute(att);
+                    if (!trackerName.isEmpty()) {
+                        SKGTrackerObject tracker(SKGObjectBase(getDocument(), QStringLiteral("refund")));  // Better performance if v_refund is not used
+                        tracker.setName(trackerName);
+                        tracker.load();
 
-                    if (tracker.isClosed()) {
-                        return m_iconClosed;
+                        if (tracker.isClosed()) {
+                            return m_iconClosed;
+                        }
                     }
                 }
             }
@@ -802,14 +811,23 @@ QVariant SKGObjectModel::computeData(const QModelIndex& iIndex, int iRole) const
                     }
                     toolTipString = op.getImportID();
                 }
-            } else if (att == QStringLiteral("t_REFUND") || att == QStringLiteral("t_REALREFUND")) {
-                QString trackerName = obj->getAttribute(att);
-                if (!trackerName.isEmpty()) {
-                    SKGTrackerObject tracker(getDocument());
-                    tracker.setName(trackerName);
-                    tracker.load();
-                    SKGServices::SKGUnitInfo unit = qobject_cast<SKGDocumentBank*>(getDocument())->getPrimaryUnit();
-                    toolTipString = SKGServices::toCurrencyString(tracker.getCurrentAmount(), unit.Symbol, unit.NbDecimal);
+            } else if (att == QStringLiteral("t_REFUND") || att == QStringLiteral("t_REALREFUND") || att == QStringLiteral("t_REFUNDDISPLAY")) {
+                if (att == QStringLiteral("t_REFUNDDISPLAY")) {
+                    if (obj->getAttribute(att).count(QStringLiteral("(")) > 1) {
+                        att.clear();
+                    } else {
+                        att = QStringLiteral("t_REFUND");
+                    }
+                }
+                if (!att.isEmpty()) {
+                    QString trackerName = obj->getAttribute(att);
+                    if (!trackerName.isEmpty()) {
+                        SKGTrackerObject tracker(getDocument());
+                        tracker.setName(trackerName);
+                        tracker.load();
+                        SKGServices::SKGUnitInfo unit = qobject_cast<SKGDocumentBank*>(getDocument())->getPrimaryUnit();
+                        toolTipString = SKGServices::toCurrencyString(tracker.getCurrentAmount(), unit.Symbol, unit.NbDecimal);
+                    }
                 }
             } else if (att == QStringLiteral("t_PAYEE")) {
                 QString payeeName = obj->getAttribute(att);
