@@ -24,13 +24,13 @@
 #include <klocalizedstring.h>
 
 #include "skgbankobject.h"
-#include "skgoperationobject.h"
-#include "skgsuboperationobject.h"
-#include "skgunitobject.h"
-#include "skginterestobject.h"
-#include "skgpayeeobject.h"
 #include "skgdocumentbank.h"
+#include "skginterestobject.h"
+#include "skgoperationobject.h"
+#include "skgpayeeobject.h"
+#include "skgsuboperationobject.h"
 #include "skgtraces.h"
+#include "skgunitobject.h"
 
 int factorial(int n)
 {
@@ -65,7 +65,7 @@ SKGAccountObject::SKGAccountObject(const SKGObjectBase& iObject)
     }
 }
 
-const SKGAccountObject& SKGAccountObject::operator= (const SKGObjectBase& iObject)
+SKGAccountObject& SKGAccountObject::operator= (const SKGObjectBase& iObject)
 {
     copyFrom(iObject);
     return *this;
@@ -75,7 +75,7 @@ SKGError SKGAccountObject::setInitialBalance(double iBalance, const SKGUnitObjec
 {
     SKGError err;
     SKGTRACEINFUNCRC(10, err);
-    if (getDocument()) {
+    if (getDocument() != nullptr) {
         // Delete previous initial balance for this account
         err = getDocument()->executeSqliteOrder("DELETE FROM operation  WHERE d_date='0000-00-00' AND rd_account_id=" % SKGServices::intToString(getID()));
 
@@ -105,7 +105,7 @@ SKGError SKGAccountObject::getInitialBalance(double& oBalance, SKGUnitObject& oU
     // Initialisation
     oBalance = 0;
     oUnit = SKGUnitObject();
-    QString unitName = static_cast<SKGDocumentBank*>(getDocument())->getPrimaryUnit().Symbol;
+    QString unitName = qobject_cast<SKGDocumentBank*>(getDocument())->getPrimaryUnit().Symbol;
 
     // Get initial balance
     SKGStringListList listTmp;
@@ -146,7 +146,7 @@ SKGError SKGAccountObject::getLinkedAccount(SKGAccountObject& oAccount) const
 SKGError SKGAccountObject::getLinkedByAccounts(SKGListSKGObjectBase& oAccounts) const
 {
     SKGError err;
-    if (getDocument()) {
+    if (getDocument() != nullptr) {
         err = getDocument()->getObjects(QStringLiteral("v_account"),
                                         "r_account_id=" % SKGServices::intToString(getID()),
                                         oAccounts);
@@ -209,7 +209,7 @@ SKGError SKGAccountObject::addOperation(SKGOperationObject& oOperation, bool iFo
 int SKGAccountObject::getNbOperation() const
 {
     int nb = 0;
-    if (getDocument()) {
+    if (getDocument() != nullptr) {
         getDocument()->getNbObjects(QStringLiteral("operation"), "rd_account_id=" % SKGServices::intToString(getID()), nb);
     }
     return nb;
@@ -218,7 +218,7 @@ int SKGAccountObject::getNbOperation() const
 SKGError SKGAccountObject::getOperations(SKGListSKGObjectBase& oOperations) const
 {
     SKGError err;
-    if (getDocument()) {
+    if (getDocument() != nullptr) {
         err = getDocument()->getObjects(QStringLiteral("v_operation"),
                                         "rd_account_id=" % SKGServices::intToString(getID()),
                                         oOperations);
@@ -231,11 +231,11 @@ double SKGAccountObject::getCurrentAmount() const
     return SKGServices::stringToDouble(getAttributeFromView(QStringLiteral("v_account_amount"), QStringLiteral("f_CURRENTAMOUNT")));
 }
 
-double SKGAccountObject::getAmount(const QDate iDate, bool iOnlyCurrencies) const
+double SKGAccountObject::getAmount(QDate iDate, bool iOnlyCurrencies) const
 {
     SKGTRACEINFUNC(10);
     double output = 0;
-    if (getDocument()) {
+    if (getDocument() != nullptr) {
         // Search result in cache
         QString ids = SKGServices::intToString(getID());
         QString dates = SKGServices::dateToSqlString(QDateTime(iDate));
@@ -309,7 +309,7 @@ SKGError SKGAccountObject::setClosed(bool iClosed)
 
 bool SKGAccountObject::isClosed() const
 {
-    return (getAttribute(QStringLiteral("t_close")) == QStringLiteral("Y") ? true : false);
+    return (getAttribute(QStringLiteral("t_close")) == QStringLiteral("Y"));
 }
 
 SKGError SKGAccountObject::bookmark(bool iBookmark)
@@ -319,7 +319,7 @@ SKGError SKGAccountObject::bookmark(bool iBookmark)
 
 bool SKGAccountObject::isBookmarked() const
 {
-    return (getAttribute(QStringLiteral("t_bookmarked")) == QStringLiteral("Y") ? true : false);
+    return (getAttribute(QStringLiteral("t_bookmarked")) == QStringLiteral("Y"));
 }
 
 SKGError SKGAccountObject::maxLimitAmountEnabled(bool iEnabled)
@@ -329,7 +329,7 @@ SKGError SKGAccountObject::maxLimitAmountEnabled(bool iEnabled)
 
 bool SKGAccountObject::isMaxLimitAmountEnabled() const
 {
-    return (getAttribute(QStringLiteral("t_maxamount_enabled")) == QStringLiteral("Y") ? true : false);
+    return (getAttribute(QStringLiteral("t_maxamount_enabled")) == QStringLiteral("Y"));
 }
 
 SKGError SKGAccountObject::setMaxLimitAmount(double iAmount)
@@ -353,7 +353,7 @@ SKGError SKGAccountObject::minLimitAmountEnabled(bool iEnabled)
 
 bool SKGAccountObject::isMinLimitAmountEnabled() const
 {
-    return (getAttribute(QStringLiteral("t_minamount_enabled")) == QStringLiteral("Y") ? true : false);
+    return (getAttribute(QStringLiteral("t_minamount_enabled")) == QStringLiteral("Y"));
 }
 
 SKGError SKGAccountObject::setMinLimitAmount(double iAmount)
@@ -370,7 +370,7 @@ double SKGAccountObject::getMinLimitAmount() const
     return SKGServices::stringToDouble(getAttribute(QStringLiteral("f_minamount")));
 }
 
-SKGError SKGAccountObject::setReconciliationDate(const QDate iDate)
+SKGError SKGAccountObject::setReconciliationDate(QDate iDate)
 {
     return setAttribute(QStringLiteral("d_reconciliationdate"), SKGServices::dateToSqlString(QDateTime(iDate)));
 }
@@ -408,7 +408,7 @@ SKGError SKGAccountObject::getUnit(SKGUnitObject& oUnit) const
             err = getDocument()->getObjects(QStringLiteral("v_unit"),
                                             "t_type IN ('1', '2', 'C') AND EXISTS(SELECT 1 FROM operation WHERE rc_unit_id=v_unit.id AND rd_account_id=" % SKGServices::intToString(getID()) % ") ORDER BY t_type", units);
             int nb = units.count();
-            if (nb) {
+            if (nb != 0) {
                 oUnit = units.at(0);
             }
         }
@@ -422,7 +422,7 @@ SKGError SKGAccountObject::addInterest(SKGInterestObject& oInterest)
     if (getID() == 0) {
         err = SKGError(ERR_FAIL, i18nc("Error message", "%1 failed because linked object is not yet saved in the database.", QStringLiteral("SKGAccountObject::addInterest")));
     } else {
-        oInterest = SKGInterestObject(static_cast<SKGDocumentBank*>(getDocument()));
+        oInterest = SKGInterestObject(qobject_cast<SKGDocumentBank*>(getDocument()));
         err = oInterest.setAccount(*this);
     }
     return err;
@@ -436,7 +436,7 @@ SKGError SKGAccountObject::getInterests(SKGListSKGObjectBase& oInterestList) con
     return err;
 }
 
-SKGError SKGAccountObject::getInterest(const QDate iDate, SKGInterestObject& oInterest) const
+SKGError SKGAccountObject::getInterest(QDate iDate, SKGInterestObject& oInterest) const
 {
     QString ids = SKGServices::intToString(getID());
     QString dates = SKGServices::dateToSqlString(QDateTime(iDate));
@@ -522,9 +522,8 @@ SKGError SKGAccountObject::getInterestItems(SKGAccountObject::SKGInterestItemLis
             for (int j = pos; !err && j < nb3; ++j) {
                 if (itemI.date <= oInterestList.at(j).date) {
                     break;
-                } else {
-                    ++pos;
                 }
+                ++pos;
             }
 
             oInterestList.insert(pos, itemI);
@@ -729,18 +728,18 @@ SKGError SKGAccountObject::computeInterestItems(SKGAccountObject::SKGInterestIte
     return err;
 }
 
-SKGError SKGAccountObject::transferDeferredOperations(const SKGAccountObject& iTargetAccount, const QDate iDate)
+SKGError SKGAccountObject::transferDeferredOperations(const SKGAccountObject& iTargetAccount, QDate iDate)
 {
     SKGError err;
     SKGTRACEINFUNCRC(10, err);
     //
-    SKGDocumentBank* doc = qobject_cast<SKGDocumentBank*>(getDocument());
-    if (doc) {
+    auto* doc = qobject_cast<SKGDocumentBank*>(getDocument());
+    if (doc != nullptr) {
         // Get pointed operations
         SKGObjectBase::SKGListSKGObjectBase operations;
         IFOKDO(err, getDocument()->getObjects(QStringLiteral("v_operation"), "rd_account_id=" % SKGServices::intToString(getID()) % " AND t_status='P'", operations))
         int nb = operations.count();
-        if (nb) {
+        if (nb != 0) {
             SKGOperationObject mergedOperations;
             SKGOperationObject balancedOperations;
             for (int i = 0; !err && i < nb; ++i) {
@@ -797,8 +796,8 @@ QVector< QVector<SKGOperationObject> > SKGAccountObject::getPossibleReconciliati
 {
     SKGTRACEINFUNC(5);
     QVector< QVector<SKGOperationObject> > output;
-    SKGDocumentBank* doc = qobject_cast<SKGDocumentBank*>(getDocument());
-    if (doc) {
+    auto* doc = qobject_cast<SKGDocumentBank*>(getDocument());
+    if (doc != nullptr) {
         // Get unit
         SKGServices::SKGUnitInfo unit1 = doc->getPrimaryUnit();
         SKGUnitObject unitAccount;
@@ -871,8 +870,8 @@ QVector< QVector<SKGOperationObject> > SKGAccountObject::getPossibleReconciliati
     SKGTRACEINFUNC(5);
     QVector< QVector<SKGOperationObject> > output;
     output.reserve(5);
-    SKGDocumentBank* doc = qobject_cast<SKGDocumentBank*>(getDocument());
-    if (doc) {
+    auto* doc = qobject_cast<SKGDocumentBank*>(getDocument());
+    if (doc != nullptr) {
         SKGTRACEL(5) << "iTargetBalance=" << doc->formatMoney(iTargetBalance, iUnit, false) << endl;
 
         // Comparison
@@ -922,7 +921,7 @@ QVector< QVector<SKGOperationObject> > SKGAccountObject::getPossibleReconciliati
                 double sumOperationPositives = 0.0;
                 double sumOperationsNegatives = 0.0;
                 for (int i = 0; i < nbNext; ++i) {
-                    SKGOperationObject op = nextOperations.at(v[i]);
+                    const SKGOperationObject& op = nextOperations.at(v[i]);
                     combi.push_back(op);
                     auto amount = op.getCurrentAmount();
                     combiAmount.push_back(amount);
@@ -1010,7 +1009,7 @@ SKGError SKGAccountObject::autoReconcile(double iBalance)
         QVector<SKGOperationObject> soluce;
         int length = 0;
         for (int i = 0; i < nbSoluces; ++i) {
-            auto s = soluces.at(i);
+            const auto& s = soluces.at(i);
             int l = s.count();
             if (l > length) {
                 soluce = s;
