@@ -22,8 +22,8 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 
-#include "skgobjectbase.h"
 #include "skgbankmodeler_export.h"
+#include "skgobjectbase.h"
 class SKGOperationObject;
 class SKGDocumentBank;
 
@@ -75,7 +75,7 @@ public:
      * Operator affectation
      * @param iObject the object to copy
      */
-    const SKGRecurrentOperationObject& operator= (const SKGObjectBase& iObject) override;
+    SKGRecurrentOperationObject& operator= (const SKGObjectBase& iObject);
 
     /**
      * Destructor
@@ -161,7 +161,7 @@ public:
      *   @see SKGError
      */
     // cppcheck-suppress passedByValue
-    SKGError setDate(const QDate iDate);
+    SKGError setDate(QDate iDate);
 
     /**
      * Get date of this recurrent operation
@@ -243,7 +243,7 @@ public:
      *   @see SKGError
      */
     // cppcheck-suppress passedByValue
-    SKGError setTimeLimit(const QDate iLastDate);
+    SKGError setTimeLimit(QDate iLastDate);
 
     /**
      * Get the number of times operation will be inserted
@@ -260,7 +260,7 @@ public:
      *   @see SKGError
      */
     // cppcheck-suppress passedByValue
-    SKGError process(int& oNbInserted, bool iForce = false, const QDate iDate = QDate::currentDate());
+    SKGError process(int& oNbInserted, bool iForce = false, QDate iDate = QDate::currentDate());
 
     /**
      * Warn and/or create operations for all recurrent operations of the document
@@ -272,7 +272,7 @@ public:
      *   @see SKGError
      */
     // cppcheck-suppress passedByValue
-    static SKGError process(SKGDocumentBank* iDocument, int& oNbInserted, bool iForce = false, const QDate iDate = QDate::currentDate());
+    static SKGError process(SKGDocumentBank* iDocument, int& oNbInserted, bool iForce = false, QDate iDate = QDate::currentDate());
 };
 /**
  * Declare the class
