@@ -759,7 +759,7 @@ QStringList SKGRuleObject::getFromXML(SKGDocument* iDocument, const QString& iXM
                                             int posSeparator = cat.indexOf(OBJECTSEPARATOR);
                                             if (posSeparator == -1) {
                                                 if (parentcat.isEmpty()) {
-                                                    output.push_back("UPDATE category SET rd_category_id=0 WHERE rd_category_id IS NULL OR rd_category_id=''");
+                                                    output.push_back(QStringLiteral("UPDATE category SET rd_category_id=0 WHERE rd_category_id IS NULL OR rd_category_id=''"));
                                                     output.push_back("INSERT OR IGNORE INTO category (t_name, rd_category_id) VALUES ('" % SKGServices::stringToSqlString(cat) % "', 0)");
                                                 } else {
                                                     output.push_back("INSERT OR IGNORE INTO category (t_name, rd_category_id) VALUES ('" % SKGServices::stringToSqlString(cat) % "',(SELECT id FROM category WHERE t_fullname='" % SKGServices::stringToSqlString(parentcat) % "'))");
@@ -770,7 +770,7 @@ QStringList SKGRuleObject::getFromXML(SKGDocument* iDocument, const QString& iXM
                                                 QString first = cat.mid(0, posSeparator);
                                                 QString second = cat.mid(posSeparator + QString(OBJECTSEPARATOR).length(), cat.length() - posSeparator - QString(OBJECTSEPARATOR).length());
                                                 if (parentcat.isEmpty()) {
-                                                    output.push_back("UPDATE category SET rd_category_id=0 WHERE rd_category_id IS NULL OR rd_category_id=''");
+                                                    output.push_back(QStringLiteral("UPDATE category SET rd_category_id=0 WHERE rd_category_id IS NULL OR rd_category_id=''"));
                                                     output.push_back("INSERT OR IGNORE INTO category (t_name, rd_category_id) VALUES ('" % SKGServices::stringToSqlString(first) % "', 0)");
                                                 } else {
                                                     output.push_back("INSERT OR IGNORE INTO category (t_name, rd_category_id) VALUES ('" % SKGServices::stringToSqlString(first) % "',(SELECT id FROM category WHERE t_fullname='" % SKGServices::stringToSqlString(parentcat) % "'))");
