@@ -22,8 +22,8 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 
-#include "skgobjectbase.h"
 #include "skgbankmodeler_export.h"
+#include "skgobjectbase.h"
 class SKGOperationObject;
 class SKGCategoryObject;
 class SKGTrackerObject;
@@ -64,12 +64,12 @@ public:
      * Operator affectation
      * @param iObject the object to copy
      */
-    const SKGSubOperationObject& operator= (const SKGObjectBase& iObject) override;
+    SKGSubOperationObject& operator= (const SKGObjectBase& iObject);
 
     /**
      * Destructor
      */
-    ~SKGSubOperationObject();
+    ~SKGSubOperationObject() override;
 
     /**
      * Set date of this suboperation
@@ -78,7 +78,7 @@ public:
      *   @see SKGError
      */
     // cppcheck-suppress passedByValue
-    SKGError setDate(const QDate iDate);
+    SKGError setDate(QDate iDate);
 
     /**
      * Get date of this suboperation
