@@ -21,23 +21,23 @@
  */
 #include "skggraphicsview.h"
 
-#include <qheaderview.h>
-#include <qmenu.h>
-#include <qdesktopservices.h>
-#include <qprinter.h>
-#include <qprintdialog.h>
-#include <qclipboard.h>
 #include <qapplication.h>
+#include <qclipboard.h>
+#include <qdesktopservices.h>
 #include <qdom.h>
-#include <qsvggenerator.h>
-#include <qgraphicssceneevent.h>
-#include <qmath.h>
 #include <qfileinfo.h>
+#include <qgraphicssceneevent.h>
+#include <qheaderview.h>
+#include <qmath.h>
+#include <qmenu.h>
+#include <qprintdialog.h>
+#include <qprinter.h>
+#include <qsvggenerator.h>
 #include <qwidgetaction.h>
 
+#include "skgmainpanel.h"
 #include "skgservices.h"
 #include "skgtraces.h"
-#include "skgmainpanel.h"
 
 SKGGraphicsView::SKGGraphicsView(QWidget* iParent)
     : QWidget(iParent), m_oscale(1), m_toolBarVisible(true)
@@ -76,7 +76,7 @@ SKGGraphicsView::SKGGraphicsView(QWidget* iParent)
     });
 
     m_actShowToolBar = m_mainMenu->addAction(SKGServices::fromTheme(QStringLiteral("show-menu")), i18nc("Noun, user action", "Show tool bar"));
-    if (m_actShowToolBar) {
+    if (m_actShowToolBar != nullptr) {
         m_actShowToolBar->setCheckable(true);
         m_actShowToolBar->setChecked(true);
         connect(m_actShowToolBar, &QAction::triggered, this, &SKGGraphicsView::onSwitchToolBarVisibility);
@@ -115,7 +115,7 @@ SKGGraphicsView::~SKGGraphicsView()
 void SKGGraphicsView::setScene(QGraphicsScene* iScene)
 {
     graphicsView()->setScene(iScene);
-    if (iScene) {
+    if (iScene != nullptr) {
         iScene->installEventFilter(this);
     }
     onZoom();
@@ -154,7 +154,7 @@ QMenu* SKGGraphicsView::getContextualMenu() const
 
 void SKGGraphicsView::showMenu(const QPoint iPos)
 {
-    if (m_mainMenu) {
+    if (m_mainMenu != nullptr) {
         m_mainMenu->popup(graphicsView()->mapToGlobal(iPos));
     }
 }
@@ -164,7 +164,7 @@ void SKGGraphicsView::setToolBarVisible(bool iVisibility)
     if (m_toolBarVisible != iVisibility) {
         m_toolBarVisible = iVisibility;
         ui.toolBar->setVisible(m_toolBarVisible);
-        if (m_actShowToolBar) {
+        if (m_actShowToolBar != nullptr) {
             m_actShowToolBar->setChecked(m_toolBarVisible);
         }
         Q_EMIT toolBarVisiblyChanged();
@@ -193,9 +193,9 @@ void SKGGraphicsView::setAntialiasing(bool iAntialiasing)
 
 bool SKGGraphicsView::eventFilter(QObject* iObject, QEvent* iEvent)
 {
-    if (iObject == graphicsView()->scene() &&  iEvent && iEvent->type() == QEvent::GraphicsSceneWheel) {
-        QGraphicsSceneWheelEvent* e = static_cast<QGraphicsSceneWheelEvent*>(iEvent);
-        if (e && e->orientation() == Qt::Vertical && QApplication::keyboardModifiers() &Qt::ControlModifier) {
+    if (iObject == graphicsView()->scene() && (iEvent != nullptr) && iEvent->type() == QEvent::GraphicsSceneWheel) {
+        auto* e = dynamic_cast<QGraphicsSceneWheelEvent*>(iEvent);
+        if ((e != nullptr) && e->orientation() == Qt::Vertical && ((QApplication::keyboardModifiers() &Qt::ControlModifier) != 0u)) {
             int numDegrees = e->delta() / 8;
             int numTicks = numDegrees / 15;
 
@@ -207,7 +207,7 @@ bool SKGGraphicsView::eventFilter(QObject* iObject, QEvent* iEvent)
             e->setAccepted(true);
             return true;
         }
-    } else if (iObject == graphicsView() &&  iEvent && iEvent->type() == QEvent::Resize) {
+    } else if (iObject == graphicsView() && (iEvent != nullptr) && iEvent->type() == QEvent::Resize) {
         Q_EMIT resized();
         if (ui.kZoom->value() == ui.kZoom->resetValue()) {
             m_timer.start(300);
@@ -225,7 +225,7 @@ void SKGGraphicsView::onZoom()
 {
     _SKGTRACEINFUNC(10);
     int sliderValue = ui.kZoom->value();
-    if (graphicsView()->scene()) {
+    if (graphicsView()->scene() != nullptr) {
         if (sliderValue == -10) {
             graphicsView()->fitInView(graphicsView()->scene()->sceneRect(), Qt::KeepAspectRatio);
             m_oscale = 1;
@@ -296,7 +296,7 @@ void SKGGraphicsView::onCopy()
 {
     _SKGTRACEINFUNC(10);
     QClipboard* clipboard = QApplication::clipboard();
-    if (clipboard) {
+    if (clipboard != nullptr) {
         QImage image(graphicsView()->size(), QImage::Format_ARGB32);
         QPainter painter(&image);
         graphicsView()->render(&painter);
