@@ -23,15 +23,15 @@
 */
 #include <kxmlguiwindow.h>
 
-#include <qurl.h>
 #include <qsystemtrayicon.h>
+#include <qurl.h>
 
-#include "skgobjectbase.h"
-#include "skgtabwidget.h"
 #include "skgbasegui_export.h"
-#include "skgtabpage.h"
 #include "skgbasegui_settings.h"
 #include "skginterfaceplugin.h"
+#include "skgobjectbase.h"
+#include "skgtabpage.h"
+#include "skgtabwidget.h"
 
 #include "ui_skgmainpanel_base.h"
 #include "ui_skgmainpanel_pref.h"
@@ -69,7 +69,7 @@ public:
      * Return the document of the main panel
      * @return document of the main panel
      */
-    virtual SKGDocument* getDocument() const;
+    SKGDocument* getDocument() const;
 
     /**
      * Creates a modal file dialog and returns the selected filename or an empty string if none was chosen.
@@ -137,32 +137,32 @@ public:
      * @return the converted QString
      */
     // cppcheck-suppress passedByValue
-    static QString dateToString(const QDate iDate);
+    static QString dateToString(QDate iDate);
 
     /**
      * Get the first selected object
      * @return first selected object
      */
-    virtual SKGObjectBase getFirstSelectedObject() const;
+    SKGObjectBase getFirstSelectedObject() const;
 
     /**
      * Get the current selection
      * @return selected objects
      */
-    virtual SKGObjectBase::SKGListSKGObjectBase getSelectedObjects() const;
+    SKGObjectBase::SKGListSKGObjectBase getSelectedObjects() const;
 
     /**
      * Get the number of selected object
      * @return number of selected objects
      */
-    virtual int getNbSelectedObjects() const;
+    int getNbSelectedObjects() const;
 
     /**
      * To know if the widget having the selection has the focus
      * Default implementation is based on mainWidget
      * @return true of false
      */
-    virtual bool hasSelectionWithFocus();
+    bool hasSelectionWithFocus();
 
     /**
      * To know if the closure of the application is authorized
@@ -174,83 +174,83 @@ public:
      * To know if the closure of the file is authorized
      * @return true if close is authorized else false
      */
-    virtual bool queryFileClose();
+    bool queryFileClose();
 
     /**
      * Return the plugin number by index
      * @param iIndex the index of the plugin
      * @return the plugin pointer. Can be nullptr. Mustn't be deleted
      */
-    virtual SKGInterfacePlugin* getPluginByIndex(int iIndex);
+    SKGInterfacePlugin* getPluginByIndex(int iIndex);
 
     /**
      * Return the plugin number by name
      * @param iName the name of the plugin
      * @return the plugin pointer. Can be nullptr. Mustn't be deleted
      */
-    virtual SKGInterfacePlugin* getPluginByName(const QString& iName);
+    SKGInterfacePlugin* getPluginByName(const QString& iName);
 
     /**
      * Get the label for normal message in status bar
      * @return the label
      */
-    virtual QLabel* statusNormalMessage() const;
+    QLabel* statusNormalMessage() const;
 
     /**
      * Get the current splash screen. nullptr if the splash screen is closed.
      * @return the splash screen
      */
-    virtual QSplashScreen* splashScreen() const;
+    QSplashScreen* splashScreen() const;
 
     /**
      * Set the main widget
      * @param iWidget the widget to display when all pages are closed
      */
-    virtual void setMainWidget(QWidget* iWidget);
+    void setMainWidget(QWidget* iWidget);
 
     /**
      * Get the tab widget.
      * @return the tab widget
      */
-    virtual SKGTabWidget* getTabWidget() const;
+    SKGTabWidget* getTabWidget() const;
 
     /**
      * Get the history item of the current page
      * @return the history item
      */
-    virtual SKGTabPage::SKGPageHistoryItem currentPageHistoryItem() const;
+    SKGTabPage::SKGPageHistoryItem currentPageHistoryItem() const;
 
     /**
      * Get the index of the current page
      * @return index of the current page
      */
-    virtual int currentPageIndex() const;
+    int currentPageIndex() const;
 
     /**
      * Get the current page
      * @return the current page
      */
-    virtual SKGTabPage* currentPage() const;
+    SKGTabPage* currentPage() const;
 
     /**
      * Get a index of a page
      * @param iPage the page
      * @return the index (-1 if not found)
      */
-    virtual int pageIndex(SKGTabPage* iPage) const;
+    int pageIndex(SKGTabPage* iPage) const;
 
     /**
      * Get a page
      * @param iIndex an index
      * @return the page
      */
-    virtual SKGTabPage* page(int iIndex) const;
+    SKGTabPage* page(int iIndex) const;
 
     /**
      * Get then number of pages
      * @return the number of pages
      */
-    virtual int countPages() const;
+    int countPages() const;
 
     /**
      * Register a global action
@@ -275,13 +275,13 @@ public:
      *                      0 to  99 is a group
      *                    100 to 200 is another group
      */
-    virtual void registerGlobalAction(const QString& iIdentifier, QAction* iAction,
-                                      bool iAddInCollection = true,
-                                      const QStringList& iListOfTable = QStringList(),
-                                      int iMinSelection = -2,
-                                      int iMaxSelection = -1,
-                                      int iRanking = -1,
-                                      bool iSelectionMustHaveFocus = false);
+    void registerGlobalAction(const QString& iIdentifier, QAction* iAction,
+                              bool iAddInCollection = true,
+                              const QStringList& iListOfTable = QStringList(),
+                              int iMinSelection = -2,
+                              int iMaxSelection = -1,
+                              int iRanking = -1,
+                              bool iSelectionMustHaveFocus = false);
 
     /**
      * Get a registered global action
@@ -289,44 +289,44 @@ public:
      * @param iWarnIfNotExist warn if the action does not exist
      * @return action pointer
      */
-    virtual QPointer<QAction> getGlobalAction(const QString& iIdentifier, bool iWarnIfNotExist = true);
+    QPointer<QAction> getGlobalAction(const QString& iIdentifier, bool iWarnIfNotExist = true);
 
     /**
      * Get a list of actions enable for a contextual menu
      * @param iTable the table
      * @return the list of actions
      */
-    virtual QList<QPointer<QAction> > getActionsForContextualMenu(const QString& iTable);
+    QList<QPointer<QAction> > getActionsForContextualMenu(const QString& iTable);
 
     /**
      * Get all registered global actions
      * @return actions
      */
-    virtual QMap<QString, QPointer<QAction> > getGlobalActions() const;
+    QMap<QString, QPointer<QAction> > getGlobalActions() const;
 
     /**
      * Get the tips of days
      * @return the tips of days
      */
-    virtual QStringList getTipsOfDay() const;
+    QStringList getTipsOfDay() const;
 
     /**
      * Get the tip of days
      * @return the tip of days
      */
-    virtual QString getTipOfDay() const;
+    QString getTipOfDay() const;
 
     /**
      * Define if the document must be saved when closed
      * @param iSaveOnClose the save on close mode
      */
-    virtual void setSaveOnClose(bool iSaveOnClose);
+    void setSaveOnClose(bool iSaveOnClose);
 
     /**
      * Get all advice
      * @return the list of advice
      */
-    virtual SKGAdviceList getAdvice() const;
+    SKGAdviceList getAdvice() const;
 
 public Q_SLOTS:
     /**
@@ -336,47 +336,47 @@ public Q_SLOTS:
      * @param iAction the associated action
      * @return the message widget
      */
-    virtual KMessageWidget* displayMessage(const QString& iMessage, SKGDocument::MessageType iType = SKGDocument::Information, const QString& iAction = QString());
+    KMessageWidget* displayMessage(const QString& iMessage, SKGDocument::MessageType iType = SKGDocument::Information, const QString& iAction = QString());
 
     /**
      * Display an error message
      * @param iMessage the error message. If the message is "", the data of the sender will be used
      * @return the message widget
      */
-    virtual KMessageWidget* displayErrorMessage(const QString& iMessage = QString());
+    KMessageWidget* displayErrorMessage(const QString& iMessage = QString());
 
     /**
      * This function is called when the application is launched again with new arguments
      * @param iArgument the arguments
      * @return the rest of arguments to treat
      */
-    virtual QStringList processArguments(const QStringList& iArgument);
+    QStringList processArguments(const QStringList& iArgument);
 
     /**
      * Set the current page
      * @param iIndex the current page
      */
-    virtual void setCurrentPage(int iIndex);
+    void setCurrentPage(int iIndex);
 
     /**
      * Set the context item visibility
      * @param iPage index of the page in the pages chooser
      * @param iVisibility the visibility
      */
-    virtual void setContextVisibility(int iPage, bool iVisibility);
+    void setContextVisibility(int iPage, bool iVisibility);
 
     /**
      * Set the context item visibility
      * @param iItem item in the pages chooser
      * @param iVisibility the visibility
      */
-    virtual void setContextVisibility(QListWidgetItem* iItem, bool iVisibility);
+    void setContextVisibility(QListWidgetItem* iItem, bool iVisibility);
 
     /**
      * Open a plugin in a page described in sender()->data()
      * @return true if the url has been opened
      */
-    virtual bool openPage();
+    bool openPage();
 
     /**
      * Open a plugin in a page
@@ -386,7 +386,7 @@ public Q_SLOTS:
      * @param iNewPage to open a new page or not
      * @return true if the url has been opened
      */
-    virtual bool openPage(const QUrl& iUrl, bool iNewPage = true);
+    bool openPage(const QUrl& iUrl, bool iNewPage = true);
 
     /**
      * Open a plugin in a page
@@ -397,7 +397,7 @@ public Q_SLOTS:
      * @param iNewPage to open a new page or not
      * @return true if the url has been opened
      */
-    virtual bool openPage(const QString& iUrl, bool iNewPage = true);
+    bool openPage(const QString& iUrl, bool iNewPage = true);
 
     /**
      * Open a plugin in a page
@@ -405,7 +405,7 @@ public Q_SLOTS:
      * @param iNewPage to open a new page or not
      * @return the opened tab
      */
-    virtual SKGTabPage* openPage(int iPage, bool iNewPage = true);
+    SKGTabPage* openPage(int iPage, bool iNewPage = true);
 
     /**
      * Open a plugin in a page
@@ -417,66 +417,66 @@ public Q_SLOTS:
      * @param iSetCurrent to set the new page as the current one
      * @return the opened tab
      */
-    virtual SKGTabPage* openPage(SKGInterfacePlugin* plugin, int index = -1, const QString& parameters = QString(), const QString& title = QString(), const QString& iID = QString(), bool iSetCurrent = true);
+    SKGTabPage* openPage(SKGInterfacePlugin* plugin, int index = -1, const QString& parameters = QString(), const QString& title = QString(), const QString& iID = QString(), bool iSetCurrent = true);
 
     /**
      * Switch the pin state of the page
      * @param iWidget the page to remove (nullptr means current one)
      */
-    virtual void switchPinPage(QWidget* iWidget);
+    void switchPinPage(QWidget* iWidget);
 
     /**
      * Close a page
      * @param iIndex the page to remove (-1 means current one)
      */
-    virtual void closePageByIndex(int iIndex = -1);
+    void closePageByIndex(int iIndex = -1);
 
     /**
      * Close a page
      * @param iWidget the page to remove (nullptr means current one)
      * @param iForce to close pinned pages too
      */
-    virtual void closePage(QWidget* iWidget, bool iForce = false);
+    void closePage(QWidget* iWidget, bool iForce = false);
 
     /**
      * Close the current page
      */
-    virtual void closeCurrentPage();
+    void closeCurrentPage();
 
     /**
      * Close all other pages
      * @param iWidget the page to keep (nullptr means current one)
      */
-    virtual void closeAllOtherPages(QWidget* iWidget);
+    void closeAllOtherPages(QWidget* iWidget);
 
     /**
      * Close all pages
      * @param iForce to close pinned pages too
      */
-    virtual void closeAllPages(bool iForce = false);
+    void closeAllPages(bool iForce = false);
 
     /**
      * Force the refresh of the object.
      */
-    virtual void refresh();
+    void refresh();
 
     /**
      * Send notifications corresponding to the transaction.
      * @param iTransaction the transaction identifier
      */
-    virtual void notify(int iTransaction = 0);
+    void notify(int iTransaction = 0);
 
     /**
      * Open settings panel on dedicated page.
      * @param iPluginName the name of the plugin (pluginInterface->objectName())
      */
-    virtual void optionsPreferences(const QString& iPluginName = QString());
+    void optionsPreferences(const QString& iPluginName = QString());
 
     /**
      * Unregister a global action
      * @param iAction action pointer
      */
-    virtual void unRegisterGlobalAction(QObject* iAction);
+    void unRegisterGlobalAction(QObject* iAction);
 
 Q_SIGNALS:
     /**
@@ -520,7 +520,7 @@ protected:
 
 private Q_SLOTS:
     KMessageWidget* getMessageWidget(const QString& iMessage, SKGDocument::MessageType iType, const QString& iAction, bool iAutoKillOnClick);
-    void showMenu(const QPoint iPos);
+    void showMenu(QPoint iPos);
 
     void onSettingsChanged();
     void onCancelCurrentAction();
