@@ -33,7 +33,7 @@ QDate SKGSimplePeriodEdit::firstDate() const
     return m_FirstDate;
 }
 
-void SKGSimplePeriodEdit::setFirstDate(const QDate iDate)
+void SKGSimplePeriodEdit::setFirstDate(QDate iDate)
 {
     if (m_FirstDate != iDate) {
         m_FirstDate = iDate;
@@ -87,20 +87,20 @@ void SKGSimplePeriodEdit::refreshList()
         QString cquarter = SKGServices::dateToPeriod(c, QStringLiteral("Q"));
         QString csemester = SKGServices::dateToPeriod(c, QStringLiteral("S"));
         QString cyear = SKGServices::dateToPeriod(c, QStringLiteral("Y"));
-        if ((cmonth != smonth && (m_Mode & PREVIOUS_MONTHS)) ||
-            (cmonth == smonth && (m_Mode & CURRENT_MONTH))) {
+        if ((cmonth != smonth && (((m_Mode & PREVIOUS_MONTHS)) != 0u)) ||
+            (cmonth == smonth && (((m_Mode & CURRENT_MONTH)) != 0u))) {
             list.insert(0, cmonth);
         }
-        if (!list.contains(cquarter) && ((cquarter != squarter && (m_Mode & PREVIOUS_PERIODS)) ||
-                                         (cquarter == squarter && (m_Mode & CURRENT_PERIOD)))) {
+        if (!list.contains(cquarter) && ((cquarter != squarter && (((m_Mode & PREVIOUS_PERIODS)) != 0u)) ||
+                                         (cquarter == squarter && (((m_Mode & CURRENT_PERIOD)) != 0u)))) {
             list.insert(0, cquarter);
         }
-        if (!list.contains(csemester) && ((csemester != ssemester && (m_Mode & PREVIOUS_PERIODS)) ||
-                                          (csemester == ssemester && (m_Mode & CURRENT_PERIOD)))) {
+        if (!list.contains(csemester) && ((csemester != ssemester && (((m_Mode & PREVIOUS_PERIODS)) != 0u)) ||
+                                          (csemester == ssemester && (((m_Mode & CURRENT_PERIOD)) != 0u)))) {
             list.insert(0, csemester);
         }
-        if (!list.contains(cyear) && ((cyear != syear && ((m_Mode & PREVIOUS_PERIODS) || (m_Mode & PREVIOUS_YEARS))) ||
-                                      (cyear == syear && ((m_Mode & CURRENT_PERIOD) || (m_Mode & CURRENT_YEAR))))) {
+        if (!list.contains(cyear) && ((cyear != syear && ((((m_Mode & PREVIOUS_PERIODS)) != 0u) || (((m_Mode & PREVIOUS_YEARS)) != 0u))) ||
+                                      (cyear == syear && ((((m_Mode & CURRENT_PERIOD)) != 0u) || (((m_Mode & CURRENT_YEAR)) != 0u))))) {
             list.insert(0, cyear);
         }
         if (cmonth == smonth || c >= today) {
@@ -115,7 +115,7 @@ void SKGSimplePeriodEdit::refreshList()
     clear();
 
     // Add dynamic items
-    if (list.contains(smonth) && (m_Mode & ALL)) {
+    if (list.contains(smonth) && (((m_Mode & ALL)) != 0u)) {
         addItem(i18nc("A period including all dates", "All dates"), "ALL");
     }
 
