@@ -81,10 +81,7 @@ public:
      * Additional information to display
      */
     Q_DECLARE_FLAGS(DisplayAdditionalFlag, DisplayAdditional)
-    /**
-     * State of the view
-     */
-    Q_PROPERTY(QString state READ getState WRITE setState CONSTANT)
+
     /**
      * Graph Type widget visibility
      */
