@@ -32,7 +32,7 @@ SKGTransactionMng::SKGTransactionMng(SKGDocument* iDocument,
     m_parentDocument = iDocument;
     m_error = iError;
     m_errorInBeginTransaction = false;
-    if (m_parentDocument && m_error) {
+    if ((m_parentDocument != nullptr) && (m_error != nullptr)) {
         *m_error = m_parentDocument->beginTransaction(iName, iNbStep, QDateTime::currentDateTime(), iRefreshViews);
         m_errorInBeginTransaction = (m_error->isFailed());
     }
@@ -40,7 +40,7 @@ SKGTransactionMng::SKGTransactionMng(SKGDocument* iDocument,
 
 SKGTransactionMng::~SKGTransactionMng()
 {
-    if (m_parentDocument && m_error) {
+    if ((m_parentDocument != nullptr) && (m_error != nullptr)) {
         // close the transaction based on error
         if (!m_errorInBeginTransaction) {
             if (m_error->isSucceeded()) {
