@@ -82,7 +82,10 @@ int main(int argc, char** argv)
         QGuiApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
     }
     QApplication app(argc, argv);
-    QApplication::setWindowIcon(SKGServices::fromTheme(QStringLiteral("skrooge")));
+    QIcon appIcon = SKGServices::fromTheme(QStringLiteral("skrooge"));
+    if (!appIcon.isNull()) {
+        app.setWindowIcon(appIcon);
+    }
 
     // Migration kf4 => kf5
     Kdelibs4ConfigMigrator migrate(QStringLiteral("skrooge"));
