@@ -627,6 +627,28 @@ int main(int argc, char** argv)
         }
     }
 
+
+    {
+        // BUG 406488
+        //
+        //"Date","Type","Number","Payee","Withdrawal (-)","Amount"
+        SKGDocumentBank document1;
+        SKGTESTERROR(QStringLiteral("document1.initialize()"), document1.initialize(), true);
+        SKGError err;
+        {
+            // Scope of the transaction
+            SKGBEGINTRANSACTION(document1, QStringLiteral("IMPORT"), err);
+            SKGImportExportManager imp1(&document1, QUrl::fromLocalFile(SKGTest::getTestPath(QStringLiteral("IN")) % "/skgtestimportcsv/406488.csv"));
+            QMap<QString, QString> parameters = imp1.getImportParameters();
+            parameters[QStringLiteral("automatic_search_columns")] = 'N';
+            parameters[QStringLiteral("columns_positions")] = QStringLiteral("date|mode|number|payee|amount|amount");
+            imp1.setImportParameters(parameters);
+            SKGError err = imp1.importFile();
+            SKGTESTERROR(QStringLiteral("CSV.importFile"), err, false);
+            SKGTEST(QStringLiteral("CSV:error message"), err.getMessage(), QStringLiteral("Invalid number of columns in line 2. Expected 6. Found 1."));
+        }
+    }
+
     {
         // Test import separator comma
         SKGDocumentBank document1;
