@@ -93,7 +93,7 @@ int main(int argc, char** argv)
         }
 
         int nb = 0;
-        SKGTESTERROR(QStringLiteral("KMY:getNbObjects(recurrentoperation)"), document1.getNbObjects(QStringLiteral("recurrentoperation"), QString(""), nb), true);
+        SKGTESTERROR(QStringLiteral("KMY:getNbObjects(recurrentoperation)"), document1.getNbObjects(QStringLiteral("recurrentoperation"), QLatin1String(""), nb), true);
         SKGTEST(QStringLiteral("KMY:getNbObjects(recurrentoperation)"), nb, 8);
     }
 
@@ -169,6 +169,20 @@ int main(int argc, char** argv)
         SKGTESTERROR(QStringLiteral("KMY:getNbObjects(operations without suboperation)"), document1.getNbObjects(QStringLiteral("operation"), QStringLiteral("NOT EXISTS (SELECT 1 FROM suboperation where rd_operation_id=operation.id)"), nb), true);
         SKGTEST(QStringLiteral("KMY:getNbObjects(operations without suboperation)"), nb, 0);
     }
+
+    {
+        // Non utf8
+        SKGDocumentBank document1;
+        SKGTESTERROR(QStringLiteral("document1.initialize()"), document1.initialize(), true);
+        SKGError err;
+        {
+            // Scope of the transaction
+            SKGBEGINTRANSACTION(document1, QStringLiteral("IMPORT_KMY"), err);
+
+            SKGImportExportManager imp1(&document1, QUrl::fromLocalFile(SKGTest::getTestPath(QStringLiteral("IN")) % "/skgtestimportkmy/non_utf8.kmy"));
+            SKGTESTERROR(QStringLiteral("KMY.importFile"), imp1.importFile(), true);
+        }
+    }
     // End test
     SKGENDTEST();
 }
