@@ -20,8 +20,8 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include "skgtestmacro.h"
-#include "skgimportexportmanager.h"
 #include "skgbankincludes.h"
+#include "skgimportexportmanager.h"
 
 /**
  * The main function of the unit test
@@ -51,7 +51,7 @@ int main(int argc, char** argv)
             SKGBEGINTRANSACTION(document1, QStringLiteral("IMPORT_INIT"), err);
             SKGImportExportManager impmissing(&document1, QUrl::fromLocalFile(QStringLiteral("missingfile.qif")));
             SKGTESTERROR(QStringLiteral("imp1.importFile"), impmissing.importFile(), false);
-            impmissing.getParameterDefaultValue(QStringLiteral("mapping_date"));
+            SKGImportExportManager::getParameterDefaultValue(QStringLiteral("mapping_date"));
 
             // Creation bank
             SKGTESTERROR(QStringLiteral("BANK:setName"), bank.setName(QStringLiteral("CREDIT COOP")), true);
@@ -220,7 +220,7 @@ int main(int argc, char** argv)
             SKGTESTERROR(QStringLiteral("QIF.findAndGroupTransfers"), imp1.findAndGroupTransfers(out), true);
             QStringList oResult;
             SKGTESTERROR(QStringLiteral("ACCOUNT:getDistinctValues"), document1.getDistinctValues(QStringLiteral("account"), QStringLiteral("t_name"), oResult), true);
-            SKGTEST(QStringLiteral("ACCOUNT:oResult.size"), oResult.size(), 2);
+            SKGTEST(QStringLiteral("ACCOUNT:oResult.size"), oResult.size(), 3);
         }
     }
 
@@ -802,44 +802,44 @@ int main(int argc, char** argv)
             SKGBEGINTRANSACTION(document1, QStringLiteral("IMPORT"), err);
 
             {
-                SKGImportExportManager imp1(&document1, QUrl::fromLocalFile(SKGTest::getTestPath(QStringLiteral("IN")) % "/skgtestimportqif1/271708/10-Compte A.qif"));
+                SKGImportExportManager imp1(&document1, QUrl::fromLocalFile(SKGTest::getTestPath(QStringLiteral("IN")) % "/skgtestimportqif1/271708/10Compte A.qif"));
                 SKGTESTERROR(QStringLiteral("QIF.importFile"), imp1.importFile(), true);
             }
             {
-                SKGImportExportManager imp1(&document1, QUrl::fromLocalFile(SKGTest::getTestPath(QStringLiteral("IN")) % "/skgtestimportqif1/271708/20-Compte B.qif"));
+                SKGImportExportManager imp1(&document1, QUrl::fromLocalFile(SKGTest::getTestPath(QStringLiteral("IN")) % "/skgtestimportqif1/271708/20Compte B.qif"));
                 SKGTESTERROR(QStringLiteral("QIF.importFile"), imp1.importFile(), true);
             }
             {
-                SKGImportExportManager imp1(&document1, QUrl::fromLocalFile(SKGTest::getTestPath(QStringLiteral("IN")) % "/skgtestimportqif1/271708/30-Compte C.qif"));
+                SKGImportExportManager imp1(&document1, QUrl::fromLocalFile(SKGTest::getTestPath(QStringLiteral("IN")) % "/skgtestimportqif1/271708/30Compte C.qif"));
                 SKGTESTERROR(QStringLiteral("QIF.importFile"), imp1.importFile(), true);
             }
             {
-                SKGImportExportManager imp1(&document1, QUrl::fromLocalFile(SKGTest::getTestPath(QStringLiteral("IN")) % "/skgtestimportqif1/271708/40-Compte D.qif"));
+                SKGImportExportManager imp1(&document1, QUrl::fromLocalFile(SKGTest::getTestPath(QStringLiteral("IN")) % "/skgtestimportqif1/271708/40Compte D.qif"));
                 SKGTESTERROR(QStringLiteral("QIF.importFile"), imp1.importFile(), true);
             }
         }
 
         {
             SKGAccountObject account(&document1);
-            SKGTESTERROR(QStringLiteral("QIF.setName"), account.setName(QStringLiteral("10 Compte A")), true);
+            SKGTESTERROR(QStringLiteral("QIF.setName"), account.setName(QStringLiteral("10Compte A")), true);
             SKGTESTERROR(QStringLiteral("QIF.load"), account.load(), true);
             SKGTEST(QStringLiteral("QIF:getValue"), SKGServices::doubleToString(account.getCurrentAmount()), QStringLiteral("0"));
         }
         {
             SKGAccountObject account(&document1);
-            SKGTESTERROR(QStringLiteral("QIF.setName"), account.setName(QStringLiteral("20 Compte B")), true);
+            SKGTESTERROR(QStringLiteral("QIF.setName"), account.setName(QStringLiteral("20Compte B")), true);
             SKGTESTERROR(QStringLiteral("QIF.load"), account.load(), true);
             SKGTEST(QStringLiteral("QIF:getValue"), SKGServices::doubleToString(account.getCurrentAmount()), QStringLiteral("10"));
         }
         {
             SKGAccountObject account(&document1);
-            SKGTESTERROR(QStringLiteral("QIF.setName"), account.setName(QStringLiteral("30 Compte C")), true);
+            SKGTESTERROR(QStringLiteral("QIF.setName"), account.setName(QStringLiteral("30Compte C")), true);
             SKGTESTERROR(QStringLiteral("QIF.load"), account.load(), true);
             SKGTEST(QStringLiteral("QIF:getValue"), SKGServices::doubleToString(account.getCurrentAmount()), QStringLiteral("20"));
         }
         {
             SKGAccountObject account(&document1);
-            SKGTESTERROR(QStringLiteral("QIF.setName"), account.setName(QStringLiteral("40 Compte D")), true);
+            SKGTESTERROR(QStringLiteral("QIF.setName"), account.setName(QStringLiteral("40Compte D")), true);
             SKGTESTERROR(QStringLiteral("QIF.load"), account.load(), true);
             SKGTEST(QStringLiteral("QIF:getValue"), SKGServices::doubleToString(account.getCurrentAmount()), QStringLiteral("40"));
         }
